@@ -37,6 +37,11 @@ sub cart_route {
 
         debug "cart_route cart name: " . $cart->name;
 
+	if (param('remove')) {
+	    # removing item from cart
+	    $cart->remove(param('remove'));
+	}
+
         if ($input = param('sku')) {
             if (scalar($input)) {
                 $product = shop_product($input);
@@ -69,6 +74,10 @@ sub cart_route {
                                name => $cart_product->name,
                                price => $cart_product->price};
 
+		if (param('quantity')) {
+		    $cart_input->{quantity} = param('quantity');
+		}
+
                 debug "Cart input: ", $cart_input;
 
                 $cart_item = $cart->add($cart_input);
